pyqode.core.widgets package
===========================

Module contents
---------------

.. automodule:: pyqode.core.widgets


Classes
-------

EncodingsContextMenu
++++++++++++++++++++

.. autoclass:: pyqode.core.widgets.EncodingsContextMenu
    :members:
    :undoc-members:
    :show-inheritance:

EncodingsComboBox
+++++++++++++++++

.. autoclass:: pyqode.core.widgets.EncodingsComboBox
    :members:
    :undoc-members:
    :show-inheritance:

EncodingsMenu
+++++++++++++

.. autoclass:: pyqode.core.widgets.EncodingsMenu
    :members:
    :undoc-members:
    :show-inheritance:

ErrorsTable
+++++++++++

.. autoclass:: pyqode.core.widgets.ErrorsTable
    :members:
    :undoc-members:
    :show-inheritance:

FileSystemContextMenu
+++++++++++++++++++++

.. autoclass:: pyqode.core.widgets.FileSystemContextMenu
    :members:
    :undoc-members:
    :show-inheritance:


FileSystemTreeView
++++++++++++++++++

.. autoclass:: pyqode.core.widgets.FileSystemTreeView
    :members:
    :undoc-members:
    :show-inheritance:


GenericCodeEdit
+++++++++++++++

.. autoclass:: pyqode.core.widgets.GenericCodeEdit
    :members:
    :undoc-members:
    :show-inheritance:

InteractiveConsole
++++++++++++++++++

.. autoclass:: pyqode.core.widgets.InteractiveConsole
    :members:
    :undoc-members:
    :show-inheritance:

MenuRecentFiles
+++++++++++++++

.. autoclass:: pyqode.core.widgets.MenuRecentFiles
    :members:
    :undoc-members:
    :show-inheritance:

OutlineTreeWidget
+++++++++++++++++

.. autoclass:: pyqode.core.widgets.OutlineTreeWidget
    :members:
    :undoc-members:
    :show-inheritance:

PromptLineEdit
++++++++++++++

.. autoclass:: pyqode.core.widgets.PromptLineEdit
    :members:
    :undoc-members:
    :show-inheritance:

RecentFilesManager
++++++++++++++++++

.. autoclass:: pyqode.core.widgets.RecentFilesManager
    :members:
    :undoc-members:
    :show-inheritance:

SplittableTabWidget
+++++++++++++++++++

.. autoclass:: pyqode.core.widgets.SplittableTabWidget
    :members:
    :undoc-members:
    :show-inheritance:

SplittableCodeEditTabWidget
+++++++++++++++++++++++++++

.. autoclass:: pyqode.core.widgets.SplittableCodeEditTabWidget
    :members:
    :undoc-members:
    :show-inheritance:

TabBar
++++++

.. autoclass:: pyqode.core.widgets.TabBar
    :members:
    :undoc-members:
    :show-inheritance:

TabWidget
+++++++++

.. autoclass:: pyqode.core.widgets.TabWidget
    :members:
    :undoc-members:
    :show-inheritance:

TextCodeEdit
++++++++++++

.. autoclass:: pyqode.core.widgets.TextCodeEdit
    :members:
    :undoc-members:
    :show-inheritance:
